# V1

Types:

```python
from medici.types import V1DeidentifyResponse, V1TranslateResponse
```

Methods:

- <code title="post /api/v1/deidentify/{pipeline}">client.v1.<a href="./src/medici/resources/v1.py">deidentify</a>(pipeline, \*\*<a href="src/medici/types/v1_deidentify_params.py">params</a>) -> <a href="./src/medici/types/v1_deidentify_response.py">V1DeidentifyResponse</a></code>
- <code title="post /api/v1/translate">client.v1.<a href="./src/medici/resources/v1.py">translate</a>(\*\*<a href="src/medici/types/v1_translate_params.py">params</a>) -> <a href="./src/medici/types/v1_translate_response.py">V1TranslateResponse</a></code>
